@@ -20,5 +20,10 @@ is_py3 = (_ver[0] == 3)
 
 if is_py2:
     from urlparse import urljoin, urlparse
+
+    str = unicode
+
 elif is_py3:
     from urllib.parse import urljoin, urlparse
+
+    str = str
