@@ -14,7 +14,7 @@ import requests
 from .compat import urljoin
 from .exceptions import LassieError
 from .filters import FILTER_MAPS
-from .utils import clean_text, convert_to_int
+from .utils import clean_text, convert_to_int, normalize_locale
 
 def merge_settings(fetch_setting, class_setting):
     """Merge settings for ``fetch``, method params have priority."""
@@ -30,7 +30,7 @@ def merge_settings(fetch_setting, class_setting):
 class Lassie(object):
     __attrs__ = [
         'open_graph', 'twitter_card', 'touch_icon', 'favicon',
-        'all_images', 'parser'
+        'all_images', 'parser', '_retreive_content'
     ]
 
     def __init__(self):
@@ -73,12 +73,12 @@ class Lassie(object):
         """
 
         # Set params, method params have priority over class params
-        open_graph = merge_settings(open_graph or self.open_graph, self.open_graph)
-        twitter_card = merge_settings(twitter_card or self.twitter_card, self.twitter_card)
-        touch_icon = merge_settings(touch_icon or self.touch_icon, self.touch_icon)
-        favicon = merge_settings(favicon or self.favicon, self.favicon)
-        all_images = merge_settings(all_images or self.all_images, self.all_images)
-        parser = merge_settings(parser or self.parser, self.parser)
+        open_graph = merge_settings(open_graph, self.open_graph)
+        twitter_card = merge_settings(twitter_card, self.twitter_card)
+        touch_icon = merge_settings(touch_icon, self.touch_icon)
+        favicon = merge_settings(favicon, self.favicon)
+        all_images = merge_settings(all_images, self.all_images)
+        parser = merge_settings(parser, self.parser)
 
         html = self._retreive_content(url)
         if not html:
@@ -109,7 +109,13 @@ class Lassie(object):
             # Maybe filter out 1x1, no "good" way to do this if image doesn't supply width/height
             data.update(self._find_all_images(soup, data))
 
-        # TODO: Find a good place for this
+        # TODO: Find a good place for setting url, title and locale
+        lang = soup.html.get('lang') if soup.html.get('lang') else soup.html.get('xml:lang')
+        if lang and (not 'locale' in data):
+            locale = normalize_locale(lang)
+            if locale:
+                data['locale'] = locale
+
         if not 'url' in data:
             data['url'] = url
 
@@ -118,7 +124,7 @@ class Lassie(object):
 
         return data
 
-    def _retreive_content(self, url):
+    def _retreive_content(self, url):  # pragma: no cover
         try:
             response = requests.get(url)
         except requests.exceptions.RequestException as e:
@@ -161,6 +167,11 @@ class Lassie(object):
                     if prop.endswith(('width', 'height')):
                         value = convert_to_int(value)
 
+                if meta_map[prop] == 'locale':
+                    locale = normalize_locale(value)
+                    if locale:
+                        data['locale'] = locale
+
                 if prop == 'keywords':
                     value = [v.strip() for v in value.split(',')]
 
@@ -229,7 +240,7 @@ class Lassie(object):
 
             height = convert_to_int(image.get('height'))
             if height:
-                image['height'] = height
+                img['height'] = height
 
             data['images'].append(img)
 
