@@ -8,6 +8,8 @@ This module contains Apple related content to help Lassie filter for content.
 
 """
 
+from ..compat import str
+
 import re
 
 APPLE_MAPS = {  # http://i.imgur.com/cla85xT.jpg
@@ -15,7 +17,7 @@ APPLE_MAPS = {  # http://i.imgur.com/cla85xT.jpg
         'touch_icon': {
             'pattern': re.compile(r"^(apple-touch-icon|apple-touch-icon-precomposed)", re.I),
             'key': 'icon',
-            'type': u'touch_icon',
+            'type': str('touch_icon'),
         },
     }
-}
\ No newline at end of file
+}
