@@ -8,6 +8,9 @@ This module contains the set of helper functions executed by Lassie methods.
 
 """
 
+from .compat import str
+
+import locale
 import re
 
 CLEANER = re.compile(r'[\r\n\t]')
@@ -32,3 +35,16 @@ def convert_to_int(value):
         return int(value)
     except TypeError:
         return None
+
+def normalize_locale(value):
+    value = value.replace('-', '_')
+    the_locale = locale.normalize(value)
+
+    if the_locale != value:
+        # Should we return the actual locale, returned from the locale lib instead of splitting?
+        try:
+            return str(the_locale.split('.')[0])
+        except IndexError:  # pragma: no cover
+            pass
+    return None
+
